@@ -10,7 +10,7 @@ conn = sqlite3.connect(db_location)
 c = conn.cursor()
 
 c.execute("DROP TABLE IF EXISTS ZipCodes;")
-c.execute("CREATE TABLE ZipCodes(zip INTEGER, city TEXT, state TEXT, longitude DOUBLE, latitude DOUBLE);")
+c.execute("CREATE TABLE ZipCodes(zip VARCHAR(5), city TEXT, state TEXT, longitude DOUBLE, latitude DOUBLE);")
 c.execute("CREATE INDEX zip_index ON ZipCodes(zip);")
 c.execute("CREATE INDEX city_index ON ZipCodes(city);")
 c.execute("CREATE INDEX state_index ON ZipCodes(state);")
@@ -26,7 +26,7 @@ for line in lines:
     state = state.strip('"')
     city = city.strip('"')
     
-    c.execute("INSERT INTO ZipCodes values(%s, '%s', '%s', %s, %s)" % (
+    c.execute("INSERT INTO ZipCodes values('%s', '%s', '%s', %s, %s)" % (
         zip,
         city,
         state,
